unit CodeRageHelpers;
interface
uses
  System.Types,
  System.SysUtils,
  System.Character;

type
  TMyCharHelper = class helper for TCharacter
    class function IsVowel(C: Char): Boolean;
  end;

type
  TIntegerHelper = record helper for Integer
    function ToString: String; inline;
  end;

type
  TDateHelper = record helper for TDate
    function ToString(Const ShortDateFormat: String = ''): String; inline;
  end;

type
  TIntegerArrayHelper = record helper for TIntegerDynArray
    function Max: Integer; inline;
    function ToString: String; inline;
  end;

type
  TMyEnum = (meNone, meAfew, meSome, meAlot);

  TMyEnumHelper = record helper for TMyEnum
    function ToString: String; inline;
  end;

implementation

{ TMyCharHelper }

class function TMyCharHelper.IsVowel(C: Char): Boolean;
begin
  Result := CharInSet(C,['a','e','i','o','u']);
end;

{ TIntegerHelper }

function TIntegerHelper.ToString: String;
begin
  Result := IntToStr(Self)
end;

{ TDateHelper }

function TDateHelper.ToString(Const ShortDateFormat: String = ''): String;
var
  LocalFormatSetting: TFormatSettings;
begin
  if ShortDateFormat <> '' then
  begin
    LocalFormatSetting.ShortDateFormat := ShortDateFormat;
    LocalFormatSetting.DateSeparator := '-';
    Result := DateToStr(Self, LocalFormatSetting);
  end
  else
    Result := DateToStr(Self)
end;

{ TIntegerArrayHelper }

function TIntegerArrayHelper.Max: Integer;
var
  i: Integer;
begin
  Result := -MaxInt;
  for i:=Low(Self) to High(Self) do
    if Self[i] > Result then
      Result := Self[i]
end;

function TIntegerArrayHelper.ToString: String;
var
  i: Integer;
begin
  Result := '';
  for I:=Low(Self) to High(Self) do
    Result := Result + Self[i].ToString + ' ';
  Result := '[' + Result + ']';
end;

{ TMyEnumHelper }

function TMyEnumHelper.ToString: String;
begin
  case Self of
    meNone: Result := 'None';
    meAfew: Result := 'A Few';
    meSome: Result := 'Some';
    meAlot: Result := 'A Lot';
  end;
end;

end.
